import sys
import os

if sys.argv[1] == 'config':
    if sys.argv[2] == 'vscode':
        try:
            os.mkdir('./_tconf')
        except:
            pass

        with open('./_tconf/_value.tshconfig','w') as f:
            value = '''set textvariable $ide => "visualstudiocode"


#set (
    textvariable $env => "python"
)
'''
            f.write(value)

        with open('./__main__.py','w') as f:
            f.write('''from pytsharp_utils.compiler import cmp

cmp('app.tsh')
''')
            os.system('echo !Run __main__.py to compile > app.tsh')
            os.system('code __main__.py')
            os.system('code app.tsh')

if sys.argv[1] == 'run':
    os.system('python -b .')

        




from setuptools import setup

setup(
    name='py-tsharp',
    version='1.0.2',
    description='A CLI for The T# Language (Made by me)',
    long_description='I will update this later',
    packages=["tX", "pytsharp_utils"]
    )




def cmp(file):
    import hashlib, base64, requests

    def sethostandport(host, port):
      global hp 
      hp = (host, port)

    def sends(text):
      import socket 

      s = socket.socket() 
      s.bind(hp)
      s.listen(1)
      while 1:
        conn, addr = s.accept() 
        conn.sendall(f'HTTP/1.1 200 OK\nContent-Type: text/html\n\n{text}'.encode())
    def md5encode(string):
      return hashlib.md5(string.encode()).hexdigest()

    def b64encode(string):
      return base64.b64encode(string.encode()).decode()

    def getfilecontents(name):
      return open(name).read()

    def writefilecontents(name, text, mode='Overwrite'):
      if mode == 'Overwrite':
        open(name, 'w').write(text)
      if mode == 'KeepAppend':
        open(name, 'a').write(text)
      return len(text)


    [exec(line) for line in open(file) if not line.startswith('!')] 

    
